pub fn manifest_root(rel_path: &str, content: &str) -> Option<ModuleRoot>Expand description
Parse one candidate file into a module root, if its basename matches
a language’s manifest spec. rel_path is repo-relative.
pub fn manifest_root(rel_path: &str, content: &str) -> Option<ModuleRoot>Parse one candidate file into a module root, if its basename matches
a language’s manifest spec. rel_path is repo-relative.